@@ -401,11 +401,6 @@ class Number(PyCMDS_Object):
         self.set_control_steps(single_step, decimals)
         # units
         self.units = units
-        self.units_kind = None
-        for kind, dic in wt_units.dicts.items():
-            if self.units in dic.keys():
-                self.units_dic = dic
-                self.units_kind = kind
         # limits
         self.limits = limits
         if self.limits is None:
@@ -420,8 +415,14 @@ class Number(PyCMDS_Object):
     def _set_limits(self):
         min_value, max_value = self.limits.read()
         limits_units = self.limits.units
-        min_value = wt_units.converter(min_value, limits_units, self.units)
-        max_value = wt_units.converter(max_value, limits_units, self.units)
+        try:
+            min_value = wt_units.converter(min_value, limits_units, self.units)
+        except ZeroDivisionError:
+            min_value = np.inf
+        try:
+            max_value = wt_units.converter(max_value, limits_units, self.units)
+        except ZeroDivisionError:
+            max_value = np.inf
         # ensure order
         min_value, max_value = [
             min([min_value, max_value]),
@@ -525,7 +526,7 @@ class Number(PyCMDS_Object):
     def give_units_combo(self, units_combo_widget):
         self.units_widget = units_combo_widget
         # add items
-        unit_types = list(self.units_dic.keys())
+        unit_types = [self.units] + list(wt_units.get_valid_conversions(self.units))
         self.units_widget.addItems(unit_types)
         # set current item
         self.units_widget.setCurrentIndex(unit_types.index(self.units))
